##  Exporting an Initiative to SAP Cloud ALM
You can export an initiative fact sheet or any subtypes as projects to SAP Cloud ALM. This creates a project in SAP Cloud ALM, but changes made in the initiative fact sheet are not updated afterward.
  1. In the synchronization setup overlay, select Export to SAP Cloud ALM.
  2. Click Create and Sync.
